@@ -46,23 +46,23 @@
 #define g_marshal_value_peek_pointer(v)  (v)->data[0].v_pointer
 #define g_marshal_value_peek_object(v)   (v)->data[0].v_pointer
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
-#endif /* G_ENABLE_DEBUG */
+#endif /* !G_ENABLE_DEBUG */
 
 /* VOID:STRING,POINTER (gtkhtml-editor-marshal.list:1) */
 void
-gtkhtml_editor_marshal_VOID__STRING_POINTER (GClosure     *closure,
-                                             GValue       *return_value G_GNUC_UNUSED,
-                                             guint         n_param_values,
+gtkhtml_editor_marshal_VOID__STRING_POINTER (GClosure *closure,
+                                             GValue *return_value G_GNUC_UNUSED,
+                                             guint n_param_values,
                                              const GValue *param_values,
-                                             gpointer      invocation_hint G_GNUC_UNUSED,
-                                             gpointer      marshal_data)
+                                             gpointer invocation_hint G_GNUC_UNUSED,
+                                             gpointer marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_POINTER) (gpointer     data1,
-                                                     gpointer     arg_1,
-                                                     gpointer     arg_2,
-                                                     gpointer     data2);
+						     gpointer     arg_1,
+						     gpointer     arg_2,
+						     gpointer     data2);
   register GMarshalFunc_VOID__STRING_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
+  register GCClosure *cc = (GCClosure *) closure;
   register gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
@@ -80,25 +80,25 @@ gtkhtml_editor_marshal_VOID__STRING_POINTER (GClosure     *closure,
   callback = (GMarshalFunc_VOID__STRING_POINTER) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_marshal_value_peek_string (param_values + 1),
-            g_marshal_value_peek_pointer (param_values + 2),
-            data2);
+	    g_marshal_value_peek_string (param_values + 1),
+	    g_marshal_value_peek_pointer (param_values + 2),
+	    data2);
 }
 
 /* STRING:STRING (gtkhtml-editor-marshal.list:2) */
 void
-gtkhtml_editor_marshal_STRING__STRING (GClosure     *closure,
-                                       GValue       *return_value G_GNUC_UNUSED,
-                                       guint         n_param_values,
+gtkhtml_editor_marshal_STRING__STRING (GClosure *closure,
+                                       GValue *return_value G_GNUC_UNUSED,
+                                       guint n_param_values,
                                        const GValue *param_values,
-                                       gpointer      invocation_hint G_GNUC_UNUSED,
-                                       gpointer      marshal_data)
+                                       gpointer invocation_hint G_GNUC_UNUSED,
+                                       gpointer marshal_data)
 {
   typedef gchar * (*GMarshalFunc_STRING__STRING) (gpointer     data1,
-                                                 gpointer     arg_1,
-                                                 gpointer     data2);
+						 gpointer     arg_1,
+						 gpointer     data2);
   register GMarshalFunc_STRING__STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
+  register GCClosure *cc = (GCClosure *) closure;
   register gpointer data1, data2;
   gchar * v_return;
 
@@ -118,8 +118,8 @@ gtkhtml_editor_marshal_STRING__STRING (GClosure     *closure,
   callback = (GMarshalFunc_STRING__STRING) (marshal_data ? marshal_data : cc->callback);
 
   v_return = callback (data1,
-                       g_marshal_value_peek_string (param_values + 1),
-                       data2);
+		       g_marshal_value_peek_string (param_values + 1),
+		       data2);
 
   g_value_take_string (return_value, v_return);
 }
